# coding: utf-8

"""
    Neuronpedia - AutoInterp Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Contact: johnny@neuronpedia.org
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neuronpedia_autointerp_client.models.score_embedding_post200_response_breakdown_inner import ScoreEmbeddingPost200ResponseBreakdownInner

class TestScoreEmbeddingPost200ResponseBreakdownInner(unittest.TestCase):
    """ScoreEmbeddingPost200ResponseBreakdownInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ScoreEmbeddingPost200ResponseBreakdownInner:
        """Test ScoreEmbeddingPost200ResponseBreakdownInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ScoreEmbeddingPost200ResponseBreakdownInner`
        """
        model = ScoreEmbeddingPost200ResponseBreakdownInner()
        if include_optional:
            return ScoreEmbeddingPost200ResponseBreakdownInner(
                text = '',
                distance = 56,
                similarity = 1.337
            )
        else:
            return ScoreEmbeddingPost200ResponseBreakdownInner(
                text = '',
                distance = 56,
                similarity = 1.337,
        )
        """

    def testScoreEmbeddingPost200ResponseBreakdownInner(self):
        """Test ScoreEmbeddingPost200ResponseBreakdownInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
