# coding: utf-8

"""
    Neuronpedia - AutoInterp Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Contact: johnny@neuronpedia.org
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neuronpedia_autointerp_client.models.np_score_fuzz_detection_type import NPScoreFuzzDetectionType

class TestNPScoreFuzzDetectionType(unittest.TestCase):
    """NPScoreFuzzDetectionType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNPScoreFuzzDetectionType(self):
        """Test NPScoreFuzzDetectionType"""
        # inst = NPScoreFuzzDetectionType()

if __name__ == '__main__':
    unittest.main()
