# coding: utf-8

"""
    Neuronpedia - AutoInterp Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Contact: johnny@neuronpedia.org
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neuronpedia_autointerp_client.models.score_fuzz_detection_post200_response import ScoreFuzzDetectionPost200Response

class TestScoreFuzzDetectionPost200Response(unittest.TestCase):
    """ScoreFuzzDetectionPost200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ScoreFuzzDetectionPost200Response:
        """Test ScoreFuzzDetectionPost200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ScoreFuzzDetectionPost200Response`
        """
        model = ScoreFuzzDetectionPost200Response()
        if include_optional:
            return ScoreFuzzDetectionPost200Response(
                score = 1.337,
                breakdown = [
                    neuronpedia_autointerp_client.models._score_fuzz_detection_post_200_response_breakdown_inner._score_fuzz_detection_post_200_response_breakdown_inner(
                        str_tokens = [
                            ''
                            ], 
                        activations = [
                            1.337
                            ], 
                        distance = 56, 
                        ground_truth = True, 
                        prediction = True, 
                        highlighted = True, 
                        probability = 1.337, 
                        correct = True, )
                    ]
            )
        else:
            return ScoreFuzzDetectionPost200Response(
                score = 1.337,
                breakdown = [
                    neuronpedia_autointerp_client.models._score_fuzz_detection_post_200_response_breakdown_inner._score_fuzz_detection_post_200_response_breakdown_inner(
                        str_tokens = [
                            ''
                            ], 
                        activations = [
                            1.337
                            ], 
                        distance = 56, 
                        ground_truth = True, 
                        prediction = True, 
                        highlighted = True, 
                        probability = 1.337, 
                        correct = True, )
                    ],
        )
        """

    def testScoreFuzzDetectionPost200Response(self):
        """Test ScoreFuzzDetectionPost200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
